unit PlugIn;

interface

uses
  Windows, Controls, Classes, StdCtrls, sysUtils;

type
  TDrawItemFunc = procedure (cHandle: HDC; Index: Integer; iString: String; Rect: TRect; State: TOwnerDrawState); stdcall;
  TGetDescriptionFunc =  function: String; stdcall;
  TGetHeight = function: Integer; stdcall;

  TPlugIn = class
  private
    FHandle: HModule;
    FDrawItem: TDrawItemFunc;
    FDescription: String;
    FItemHeight: Integer;
  public
    constructor Create(FileName: String);
    destructor Destroy; override;
    procedure DrawItem(Control: TWinControl; Index: Integer; Rect: TRect; State: TOwnerDrawState);
    property Description: String read FDescription;
    property ItemHeight: Integer read FItemHeight;
  end;

implementation

{ TPlugIn }

constructor TPlugIn.Create(FileName: String);
var
  Desc: TGetDescriptionFunc;
  iHeight: TGetHeight;
begin
  FHandle := LoadLibrary(PChar(FileName));
  if FHandle <> 0 then
  begin
    FDrawItem := GetProcAddress(FHandle, 'DrawItem');
    Desc := GetProcAddress(FHandle, 'GetDescription');
    iHeight := GetProcAddress(FHandle, 'GetHeight');
    if Assigned(FDrawItem) and Assigned(Desc) and Assigned(iHeight) then
    begin
      FDescription := Desc;
      FItemHeight := iHeight;
    end
    else
    begin
      FreeLibrary(FHandle);
      raise Exception.Create('Greska prilikom ucitavanja plugin-a');
    end;
  end
  else
    raise Exception.Create('Greska prilikom ucitavanja plugin-a');
end;

destructor TPlugIn.Destroy;
begin
  FreeLibrary(FHandle);
  inherited;
end;

procedure TPlugIn.DrawItem(Control: TWinControl; Index: Integer;
  Rect: TRect; State: TOwnerDrawState);
begin
  FDrawItem(TListBox(Control).Canvas.Handle, Index, TListBox(Control).Items[Index], Rect, State);
end;

end.
